/**
 * tlssep_status_t:
 * @TLSSEP_STATUS_OK: No error
 * @TLSSEP_STATUS_AGAIN: Try again
 * @TLSSEP_STATUS_ERROR: Generic error
 * @TLSSEP_STATUS_ERROR_TLS: Generic TLS error
 * @TLSSEP_STATUS_ERROR_TLS_CONNECT: Error connecting TLS
 * @TLSSEP_STATUS_ERROR_TLS_ACCEPT: Error accepting TLS
 * @TLSSEP_STATUS_ERROR_TLS_WRITE: Error writing TLS
 * @TLSSEP_STATUS_ERROR_TLS_READ: Error reading TLS
 * @TLSSEP_STATUS_ERROR_RPC_FAILURE: RPC failure
 * @TLSSEP_STATUS_ERROR_ALLOCATION_FAILED: Error allocating memory
 * @TLSSEP_STATUS_ERROR_POLL_FAILED: Error polling decorator
 * @TLSSEP_STATUS_ERROR_SOCKET_FAILED: Error setting up a socket
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_EXIT: Bad exit code from decorator
 * @TLSSEP_STATUS_ERROR_DECORATOR_FORK: Fork decorator error
 * @TLSSEP_STATUS_ERROR_DECORATOR_MISSING: Decorator missing
 * @TLSSEP_STATUS_ERROR_DESCRIPTORS_EXHAUSTED: No more descriptors available
 * @TLSSEP_STATUS_ERROR_TRANSMITTING_FILE_DESCRIPTOR: Error transmitting file descriptor
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERT_PATH: Decorator bad certificate path
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_PRIVKEY_PATH: Decorator bad private key path
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CA_PATH: Decorator bad CA path
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_VERIFICATION_ENGINE: Bad verification engine
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE: Bad certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE: Missing certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE_CHAIN: Could not extract peer certificate chain
 * @TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_MISMATCH: Unexpected name in certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_NAME_CONTAINS_NULL: Name in certificate contains 0x00
 *
 * Enum values used to specify status conditions.
 */
typedef enum tlssep_status_t {
	TLSSEP_STATUS_OK,
	TLSSEP_STATUS_AGAIN,
	TLSSEP_STATUS_ERROR,
	TLSSEP_STATUS_ERROR_TLS,
	TLSSEP_STATUS_ERROR_TLS_CONNECT,
	TLSSEP_STATUS_ERROR_TLS_ACCEPT,
	TLSSEP_STATUS_ERROR_TLS_WRITE,
	TLSSEP_STATUS_ERROR_TLS_READ,
	TLSSEP_STATUS_ERROR_RPC_FAILURE,
	TLSSEP_STATUS_ERROR_ALLOCATION_FAILED,
	TLSSEP_STATUS_ERROR_POLL_FAILED,
	TLSSEP_STATUS_ERROR_SOCKET_FAILED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_EXIT,
	TLSSEP_STATUS_ERROR_DECORATOR_FORK,
	TLSSEP_STATUS_ERROR_DECORATOR_MISSING,
	TLSSEP_STATUS_ERROR_DESCRIPTORS_EXHAUSTED,
	TLSSEP_STATUS_ERROR_TRANSMITTING_FILE_DESCRIPTOR,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERT_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_PRIVKEY_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CA_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_VERIFICATION_ENGINE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE,
	TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE,
	TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE_CHAIN,
	TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_MISMATCH,
	TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_NAME_CONTAINS_NULL,
	/*< private >*/
 	TLSSEP_STATUS_LAST,
 } tlssep_status_t;
